==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Encyclopedia/language/lang-french.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/




define("_PREVIOUS","Page Pr&eacute;c&eacute;dente");
define("_NEXT","Page Suivante");

define("_SEARCHRESULTS","R&eacute;sultats de la recherche");
define("_PAGE","Page");
define("_RETURNTO","Retour &agrave;");
define("_DEACTIVATE","D&eacute;sactiver");
define("_ACTIVATE","Activer");
define("_ENCYCLOPEDIA","Encyclopdie");
define("_NOCONTENTFORLETTER","Dsol, il n'y a aucun contenu pour cette lettre");
define("_ENCYSELECTLETTER","Merci de choisir un lettre dans la liste suivante pour consulter son contenu:");
define("_COPYRIGHT","Copyright &copy; par $sitename. Tous droits rservs.");
define("_YOURADMINENCY","Vous tes un administrateur, cette encyclopdie n'est pas active!");
define("_ENCYNOTACTIVE","Dsol, cette encyclopdie n'est pour le moment pas active.");
define("_AVAILABLEENCYLIST","Liste des encyclopdies accessible dans");
define("_YOURADMININACTIVELIST","Vous tes un administrateur: regardez la liste des encyclopdies inactives:");
define("_NORESULTSTEXT","Aucun rsultats dans le texte du terme...");
define("_NORESULTSTITLE","Aucun rsultats dans le titre du terme...");
define("_SEARCHRESULTSFOR","Rsultats de la recherche pour:");
define("_SEARCHNOTCOMPLETE","Les options de la recherche sont incompltes. Merci de recommencer.");
define("_RESULTSINTERMTITLE","Rsultats dans le titre du terme:");
define("_RESULTSINTERMTEXT","Rsultats dans le texte du terme:");


?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Encyclopedia/language/lang-french.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/




define("_PREVIOUS","Page Pr&eacute;c&eacute;dente");
define("_NEXT","Page Suivante");

define("_SEARCHRESULTS","R&eacute;sultats de la recherche");
define("_PAGE","Page");
define("_RETURNTO","Retour &agrave;");
define("_DEACTIVATE","D&eacute;sactiver");
define("_ACTIVATE","Activer");
define("_ENCYCLOPEDIA","Encyclopdie");
define("_NOCONTENTFORLETTER","Dsol, il n'y a aucun contenu pour cette lettre");
define("_ENCYSELECTLETTER","Merci de choisir un lettre dans la liste suivante pour consulter son contenu:");
define("_COPYRIGHT","Copyright &copy; par $sitename. Tous droits rservs.");
define("_YOURADMINENCY","Vous tes un administrateur, cette encyclopdie n'est pas active!");
define("_ENCYNOTACTIVE","Dsol, cette encyclopdie n'est pour le moment pas active.");
define("_AVAILABLEENCYLIST","Liste des encyclopdies accessible dans");
define("_YOURADMININACTIVELIST","Vous tes un administrateur: regardez la liste des encyclopdies inactives:");
define("_NORESULTSTEXT","Aucun rsultats dans le texte du terme...");
define("_NORESULTSTITLE","Aucun rsultats dans le titre du terme...");
define("_SEARCHRESULTSFOR","Rsultats de la recherche pour:");
define("_SEARCHNOTCOMPLETE","Les options de la recherche sont incompltes. Merci de recommencer.");
define("_RESULTSINTERMTITLE","Rsultats dans le titre du terme:");
define("_RESULTSINTERMTEXT","Rsultats dans le texte du terme:");


?>
